@@ -1,2 +1,2 @@
 from pyretest.pooled_kappa import pooled_cohen_kappa, bootstrap_sample_size_cohen_kappa, bootstrap_confidence_interval
-from pyretest.sampler import sample_questionnaire, Question
+from pyretest.sampler import sample_questionnaire, Question, make_reliable
